@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Time::C;
-$Time::C::VERSION = '0.015';
+$Time::C::VERSION = '0.016';
 # ABSTRACT: Convenient time manipulation.
 
 use overload (
@@ -63,7 +63,10 @@ method mktime ($c: :$epoch =, :$second =, :$minute =, :$hour =, :$mday =, :$mont
                 $t = Time::C->new($year, $month);
             }
         } elsif (defined $week) {
-            $t = Time::C->new($year)->week($week)->day_of_week(1);
+            $t = Time::C->new($year);
+            $t->day++ while ($t->week > 1);
+            $t = $t->week($week)->day_of_week(1);
+
             if (defined $wday) { $t->day_of_week = $wday; }
         } elsif (defined $yday) {
             $t = Time::C->new($year)->day($yday);
@@ -90,7 +93,9 @@ method mktime ($c: :$epoch =, :$second =, :$minute =, :$hour =, :$mday =, :$mont
             if (defined $minute) { $t->minute = $minute; }
             if (defined $second) { $t->second = $second; }
         } elsif (defined $week) {
-            $t = Time::C->new($year)->week($week)->day_of_week(1);
+            $t = Time::C->new($year);
+            $t->day++ while ($t->week > 1);
+            $t = $t->week($week)->day_of_week(1);
             if (defined $wday) { $t->day_of_week = $wday; }
 
             # Now add the time bits on top...
@@ -577,7 +582,7 @@ Time::C - Convenient time manipulation.
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 SYNOPSIS
 
